@@ -6,7 +6,7 @@ void Block::dollarIndex(size_t lineNr, string const &text, bool member)
 {
     d_atDollar.push_back(
         AtDollar(AtDollar::DOLLAR, length(), lineNr, 
-                 text, A2x(text.substr(1)), member)
+                 text, stol(text.substr(1)), member)
     );
     append(text);
 }
