@@ -4,10 +4,10 @@ FollowSet &FollowSet::operator+=(FirstSet const &firstSet)
 {
                                     // As the elements are always Terminals, 
                                     // I can apply a reinterpret_cast here
-    set<Terminal const *> const *sourceSet =     
+    auto sourceSet = 
             reinterpret_cast<set<Terminal const *> const *>(&firstSet);
 
-    insert(sourceSet->begin(), sourceSet->end());
+    d_set.insert(sourceSet->begin(), sourceSet->end());
 
     return *this;
 }
