@@ -12,6 +12,6 @@ void Generator::debugIncludes(ostream &out) const
     out <<  "#include <iostream>\n"
             "#include <sstream>\n"
             "#include <string>\n"
-            "#include <map>\n"
+            "#include <unordered_map>\n"
             "#include <iomanip>\n";
 }
