@@ -4,12 +4,7 @@ void Generator::print(ostream &out) const
 {
     key(out);
 
-    out << "inline void " << d_parser.className() << "::print()\n"
-            "{";
-
-    if (!d_print)
-        out << "}\n";
-    else
+    if (d_printTokens)
         out <<
             "\n"
                     // _UNDETERMINED_ is also used in writer/symbolicnames.cc
@@ -20,7 +15,6 @@ void Generator::print(ostream &out) const
             "        if (d_token__ == _UNDETERMINED_)\n"
             "            std::cout << \"'\\n\";\n"
             "        else\n"
-            "            std::cout << " << *d_matchedTextFunction << 
-                                                            " << \"'\\n\";\n"
-            "}\n";
+            "            std::cout << " << d_matchedTextFunction << 
+                                                            " << \"'\\n\";\n";
 }
