@@ -85,6 +85,7 @@ class NonTerminal: public Symbol
         virtual std::ostream &insert(std::ostream &out) const;
         virtual size_t v_value() const;
         virtual FirstSet const &v_firstSet() const;
+
         std::ostream &insName(std::ostream &out) const;
 };
 
@@ -159,11 +160,6 @@ inline std::set<Element const *> const &NonTerminal::firstTerminals() const
     return d_first.set();
 }
 
-inline FirstSet const &NonTerminal::v_firstSet() const
-{
-    return d_first;
-}
-
 inline void NonTerminal::addProduction(Production *next)
 {
     d_production.push_back(next);
@@ -174,11 +170,6 @@ inline size_t NonTerminal::nProductions() const
     return d_production.size();
 }
 
-inline size_t NonTerminal::v_value() const
-{
-    return d_nr;
-}
-
 inline void NonTerminal::addEpsilon() 
 {
     d_first.addEpsilon();
@@ -219,11 +210,6 @@ inline void NonTerminal::addToFollow(NonTerminal const *nonTerminal)
     d_follow += nonTerminal->d_follow;
 }
 
-inline std::ostream &NonTerminal::insert(std::ostream &out) const
-{
-    return (this->*NonTerminal::s_insertPtr)(out);
-}
-
 inline void NonTerminal::inserter(std::ostream &(NonTerminal::*insertPtr)
                                            (std::ostream &out) const)
 {
