@@ -2,7 +2,7 @@
 #define INCLUDED_OPTIONS_
 
 #include <string>
-#include <bobcat/a2x>
+#include <set>
 
 namespace FBB
 {
@@ -11,6 +11,12 @@ namespace FBB
 
 class Options
 {
+    enum PathType
+    {
+        FILENAME,
+        PATHNAME
+    };
+
     FBB::Arg &d_arg;
 
     std::string const *d_matched;
@@ -29,6 +35,11 @@ class Options
 
     size_t      d_requiredTokens;
 
+    std::set<std::string> d_warnOptions;    // contains the names of options 
+                                            // for which Generator may warn
+                                            // if specified for already
+                                            // existing .h or .ih files
+
     std::string d_baseClassHeader;
     std::string d_baseClassSkeleton;
     std::string d_polymorphicInline;
@@ -48,6 +59,7 @@ class Options
     std::string d_scannerInclude;
     std::string d_scannerMatchedTextFunction;
     std::string d_scannerTokenFunction;
+    std::string d_scannerClassName;
     std::string d_skeletonDirectory;
     std::string d_stackDecl;
     std::string d_targetDirectory;
@@ -63,6 +75,7 @@ class Options
     static char s_defaultParsefunSource[];
     static char s_defaultSkeletonDirectory[];
     static char s_defaultTargetDirectory[];
+    static char s_defaultScannerClassName[];
     static char s_defaultScannerMatchedTextFunction[];
     static char s_defaultScannerTokenFunction[];
     static char s_YYText[];
@@ -79,6 +92,8 @@ class Options
 
         void setAccessorVariables();
 
+        bool specified(std::string const &option) const;
+
         void setBaseClassHeader();
         void setBaseClassSkeleton();
         void setClassHeader();
@@ -99,6 +114,7 @@ class Options
         void setPrintTokens();
         void setPreInclude();
         void setRequiredTokens(size_t nRequiredTokens);
+        void setScannerClassName();
         void setScannerInclude();
         void setScannerMatchedTextFunction();
         void setScannerTokenFunction();
@@ -125,6 +141,7 @@ class Options
 
         std::string const &baseClassSkeleton() const;
         std::string const &baseClassHeader() const;
+        std::string baseclassHeaderName() const;
         std::string const &classHeader() const;
         std::string const &className() const;
         std::string const &classSkeleton() const;
@@ -137,6 +154,7 @@ class Options
         std::string const &preInclude() const;
         std::string const &polymorphicInlineSkeleton() const;
         std::string const &polymorphicSkeleton() const;
+        std::string const &scannerClassName() const;
         std::string const &scannerInclude() const;
         std::string const &scannerMatchedTextFunction() const;
         std::string const &scannerTokenFunction() const;
@@ -149,21 +167,27 @@ class Options
 
             // called by setAccessorVariables()
         void setBooleans();
-        bool setBasicStrings();
+        void setBasicStrings();
         std::string setOpt(char const *opt, std::string const &defaultSpec);
         void setQuotedStrings();
-        void setPathStrings(bool targetDirOption);
+        void setPathStrings();  // called by setAccessorVariables,
+                                // called by parser.cleanup(). 
+                                // inspected Option values
+                                // may NOT have directory separators.
         void setSkeletons();
         
-
-        void cleanDir(std::string &dir); // undelimit and append / if missing
+                             // undelimit and if append append / if missing
+        void cleanDir(std::string &dir, bool append); 
         void addIncludeQuotes(std::string &target);
 
-        void assign(std::string *target, char const *declTxt);
+        std::string const &accept(PathType pathType, char const *declTxt);
+        void assign(std::string *target, PathType pathType, 
+                    char const *declTxt);
 
-        void setPath(std::string *dest, int optChar, bool targetDirOption, 
-                      char const *optionName, std::string const &className, 
-                      char const *suffix);
+        void setPath(std::string *dest, int optChar, 
+                      std::string const &defaultFilename, 
+                      char const *defaultSuffix,
+                      char const *optionName);
 
         bool isFirstStypeDefinition() const;
 };
@@ -273,6 +297,11 @@ inline size_t Options::requiredTokens() const
     return d_requiredTokens;
 }
 
+inline std::string const &Options::scannerClassName() const
+{
+    return d_scannerClassName;
+}
+
 inline std::string const &Options::scannerInclude() const
 {
     return d_scannerInclude;
@@ -290,22 +319,22 @@ inline std::string const &Options::scannerTokenFunction() const
 
 inline void Options::setBaseClassHeader()
 {
-    assign(&d_baseClassHeader, "baseclass-header");
+    assign(&d_baseClassHeader, FILENAME, "baseclass-header");
 }
 
 inline void Options::setBaseClassSkeleton()
 {
-    assign(&d_baseClassSkeleton, "baseclass-skeleton");
+    assign(&d_baseClassSkeleton, PATHNAME, "baseclass-skeleton");
 }
 
 inline void Options::setClassHeader()
 {
-    assign(&d_classHeader, "class-header");
+    assign(&d_classHeader, FILENAME, "class-header");
 }
 
 inline void Options::setClassName()
 {
-    assign(&d_className, "class-name");
+    assign(&d_className, FILENAME, "class-name");
 }
 
 inline void Options::setErrorVerbose()
@@ -320,7 +349,7 @@ inline void Options::setDebug()
 
 inline void Options::setGenericFilename()
 {
-    assign(&d_genericFilename, "filenames");
+    assign(&d_genericFilename, FILENAME, "filenames");
 }
 
 inline void Options::setFlex()
@@ -330,7 +359,7 @@ inline void Options::setFlex()
 
 inline void Options::setImplementationHeader()
 {
-    assign(&d_implementationHeader, "implementation-header");
+    assign(&d_implementationHeader, FILENAME, "implementation-header");
 }
 
 inline void Options::unsetLines()
@@ -350,57 +379,59 @@ inline void Options::setMatched(std::string const &matched)
 
 inline void Options::setNamespace()
 {
-    assign(&d_nameSpace, "namespace");
+    assign(&d_nameSpace, FILENAME, "namespace");
 }
 
 inline void Options::setParsefunSource()
 {
-    assign(&d_parsefunSource, "parsefun-source");
+    assign(&d_parsefunSource, FILENAME, "parsefun-source");
 }
 
 inline void Options::setPolymorphicInlineSkeleton()
 {
-    assign(&d_polymorphicInlineSkeleton, "polymorphic-inline-skeleton");
+    assign(&d_polymorphicInlineSkeleton, 
+                            PATHNAME, "polymorphic-inline-skeleton");
 }
 
 inline void Options::setPolymorphicSkeleton()
 {
-    assign(&d_polymorphicSkeleton, "polymorphic-skeleton");
+    assign(&d_polymorphicSkeleton, PATHNAME, "polymorphic-skeleton");
 }
 
 inline void Options::setPreInclude()
 {
-    assign(&d_preInclude, "baseclass-preinclude");
+    assign(&d_preInclude, FILENAME, "baseclass-preinclude");
+}
+
+inline void Options::setScannerClassName()
+{
+    assign(&d_scannerClassName, FILENAME, "scanner-class-name");
 }
 
 inline void Options::setScannerInclude()
 {
-    assign(&d_scannerInclude, "scanner");
+    assign(&d_scannerInclude, PATHNAME, "scanner");
 }
 
 inline void Options::setScannerMatchedTextFunction()
 {
-    assign(&d_scannerMatchedTextFunction, "scanner-matched-text-function");
-}
-
-inline void Options::setPrintTokens()
-{
-    d_printTokens = true;
+    assign(&d_scannerMatchedTextFunction, 
+                                FILENAME, "scanner-matched-text-function");
 }
 
 inline void Options::setScannerTokenFunction()
 {
-    assign(&d_scannerTokenFunction, "scanner-token-function");
+    assign(&d_scannerTokenFunction, FILENAME, "scanner-token-function");
 }
 
 inline void Options::setSkeletonDirectory()
 {
-    assign(&d_skeletonDirectory, "skeleton-directory (-S)");
+    assign(&d_skeletonDirectory, PATHNAME, "skeleton-directory (-S)");
 }
 
 inline void Options::setTargetDirectory()
 {
-    assign(&d_targetDirectory, "target-directory");
+    assign(&d_targetDirectory, PATHNAME, "target-directory");
 }
 
 inline std::string const &Options::stype() const
@@ -418,4 +449,9 @@ inline void Options::unsetStrongTags()
     d_strongTags = false;
 }
 
+inline bool Options::specified(std::string const &option) const
+{
+    return d_warnOptions.find(option) != d_warnOptions.end();
+}
+
 #endif
