@@ -5,11 +5,9 @@ void Parser::checkEmptyBlocktype()
     string const &stype = d_rules.sType();
 
     if (stype.size())           // return type is required
-        lineMsg(wmsg) << 
+        wmsg << 
             "rule `" << d_rules.name() << 
             "': no return type for empty production rule of typed "
                                                     "nonterminal" << endl;
-// Not shown in 2.8.0:
-//    lineMsg(imsg) << "      <empty>" << endl;
 }
 
