@@ -1,6 +1,6 @@
 #include "parser.ih"
 
-void Parser::handleProductionElement(spSemBase const &last)
+void Parser::handleProductionElement(STYPE__ &last)
 {
         // maybe also when currentRule == 0 ? See addProduction
     if (!d_rules.hasRules())    // may happen if the first rule could not be
@@ -14,16 +14,16 @@ void Parser::handleProductionElement(spSemBase const &last)
 
     switch (last->tag())
     {
-        case Tag::TERMINAL:
-            d_rules.addElement(last->as<Tag::TERMINAL>());
+        case Tag__::TERMINAL:
+            d_rules.addElement(last->get<Tag__::TERMINAL>());
             checkFirstType();
         break;
-        case Tag::SYMBOL:
-            d_rules.addElement(last->as<Tag::SYMBOL>());
+        case Tag__::SYMBOL:
+            d_rules.addElement(last->get<Tag__::SYMBOL>());
             checkFirstType();
         break;
-        case Tag::BLOCK:
-            installAction(last->as<Tag::BLOCK>());
+        case Tag__::BLOCK:
+            installAction(last->get<Tag__::BLOCK>());
         break;
 
         default:            // can't occur, but used to keep the 
