@@ -5,14 +5,13 @@ void Rules::showFollow() const
     if (!Arg::instance().option(0, "construction"))
         return;
 
-    msg() << info;
-
-    msgstream() << "FOLLOW sets:\n";
+    imsg << "\n"
+            "FOLLOW sets:\n";
 
     NonTerminal::inserter(&NonTerminal::nameAndFollowset);
 
     copy(d_nonTerminal.begin(), d_nonTerminal.end(), 
-                ostream_iterator<NonTerminal const *>(msgstream(), "\n"));
+                ostream_iterator<NonTerminal const *>(imsg, "\n"));
 
-    msgstream() << info;
+    imsg << endl;
 }
