@@ -1,5 +1,5 @@
-#ifndef \@_h_included
-#define \@_h_included
+#ifndef \@$_h_included
+#define \@$_h_included
 
 $insert baseclass
 $insert scanner.h
@@ -26,6 +26,7 @@ $insert 4 scannerobject
         int lookup(bool recovery);
         void nextToken();
         void print__();
+        void exceptionHandler__(std::exception const &exc);
 };
 
 $insert namespace-close
