@@ -1,6 +1,7 @@
-#ifndef \@Base_h_included
-#define \@Base_h_included
+#ifndef \@$Base_h_included
+#define \@$Base_h_included
 
+#include <exception>
 #include <vector>
 #include <iostream>
 
