@@ -4,8 +4,8 @@ void State::addState(Item::Vector const &kernel)
 {
     State &state = newState();
 
-    for_each(kernel.begin(), kernel.end(), 
-         FnWrap::unary(staticAddKernelItem, state));
+    for (auto &item: kernel)
+        state.addKernelItem(StateItem(item));
 }
 
 
