@@ -2,15 +2,14 @@
 
 void State::allStates()
 {
-    if (!Msg::display())
+    if (!imsg.isActive())
         return;
 
-    msg() << info;
-
-    msg() << "Grammar States: " << info;
+    imsg << "\n"
+            "Grammar States: " << endl;
 
     if (s_insert == &State::insertExt)
-        msg() << 
+        imsg << 
     "\n"
     "For each state information like the following is shown for its items:\n"
     "   0: [P1 1] S -> C  . C   { <EOF> }  0, (1 2 ) 0\n"
@@ -33,13 +32,20 @@ void State::allStates()
     "   0:               The Next table's index\n"
     "   On C to state 5: When C was recognized, continue at state 5\n"
     "   with (0 )        The item(s) whose dot is shifted at the next state\n"
-    "Also, reduction item(s) may be listed\n" << info;
-
-    msg() << info;
+    "Indices (like 0:) may be annotated as follows:\n"
+    "   0 (AUTO REMOVED by S/R resolution): On C ...\n"
+    "       in which case a reduction using a production with unspecified\n"
+    "       precedence took priority;\n"
+    "or:\n"
+    "   0 (removed by precedence): On C ...\n"
+    "       in which case a production rule's precedence took priority\n"
+    "Also, reduction item(s) may be listed\n"
+    "\n"
+    "\n";
 
     copy(s_state.begin(), s_state.end(), 
-                ostream_iterator<State const *>(msgstream(), "\n"));
+                ostream_iterator<State const *>(imsg, "\n"));
 
-    msgstream() << info;
+    imsg << endl;
 }
 
