@@ -48,11 +48,6 @@ void usage(string const &program_name)
     "   --filenames=<filename> (-f):\n"
     "           filename of output files (overruling the default filename).\n"
 
-    "   --force-class-header: overwrite an existing class header file.\n"
-
-    "   --force-implementation-header: overwrite an existing implementation\n"
-    "           header file.\n"
-
     "   --help (-h): produce this information (and terminate).\n"
 
     "   --implementation-header=<header> (-i):\n"
@@ -116,6 +111,10 @@ void usage(string const &program_name)
     "           include `header-file' declaring the class Scanner, and call\n"
     "           d_scanner.yylex() from Parser::lex().\n"
 
+    "   --scanner-class-name=<scanner class name>:\n"
+    "           specifies the name of the scanner class: this option is\n"
+    "           only interpreted if --scanner (or %scanner) is also used.\n"
+
     "   --scanner-debug: extensive display of the actions of bisonc++'s "
                                                                 "scanner\n"
 
